@@ -12,16 +12,21 @@ class Tenants(object):
 
         telemetry (bool, optional): Enable or disable Telemetry
             (defaults to True)
+
+        timeout (float or tuple, optional): Change the requests
+            connect and read timeout. Pass a tuple to specify
+            both values separately or a float to set both to it.
+            (defaults to 5.0 for both)
     """
 
-    def __init__(self, domain, token, telemetry=True):
+    def __init__(self, domain, token, telemetry=True, timeout=5.0):
         self.domain = domain
-        self.client = RestClient(jwt=token, telemetry=telemetry)
+        self.client = RestClient(jwt=token, telemetry=telemetry, timeout=timeout)
 
     def _url(self):
-        return 'https://%s/api/v2/tenants/settings' % self.domain
+        return 'https://{}/api/v2/tenants/settings'.format(self.domain)
 
-    def get(self, fields=[], include_fields=True):
+    def get(self, fields=None, include_fields=True):
         """Get tenant settings.
 
         Args:
@@ -30,10 +35,12 @@ class Tenants(object):
               retrieve all fields.
 
            include_fields (bool, optional): True if the fields specified are
-              to be include in the result, False otherwise.
+              to be included in the result, False otherwise.
+              
+           See: https://auth0.com/docs/api/management/v2#!/Tenants/get_settings
         """
 
-        params = {'fields': ','.join(fields) or None,
+        params = {'fields': fields and ','.join(fields) or None,
                   'include_fields': str(include_fields).lower()}
 
         return self.client.get(self._url(), params=params)
