@@ -1,4 +1,5 @@
 from .rest import RestClient
+import warnings
 
 
 class Users(object):
@@ -12,11 +13,16 @@ class Users(object):
 
         telemetry (bool, optional): Enable or disable Telemetry
             (defaults to True)
+
+        timeout (float or tuple, optional): Change the requests
+            connect and read timeout. Pass a tuple to specify
+            both values separately or a float to set both to it.
+            (defaults to 5.0 for both)
     """
 
-    def __init__(self, domain, token, telemetry=True):
+    def __init__(self, domain, token, telemetry=True, timeout=5.0):
         self.domain = domain
-        self.client = RestClient(jwt=token, telemetry=telemetry)
+        self.client = RestClient(jwt=token, telemetry=telemetry, timeout=timeout)
 
     def _url(self, id=None):
         url = 'https://{}/api/v2/users'.format(self.domain)
@@ -82,9 +88,11 @@ class Users(object):
 
     def delete_all_users(self):
         """Deletes all users (USE WITH CAUTION).
+        Deprecation: This endpoint is no longer available server-side.
 
         Args:
         """
+        warnings.warn("DELETE all users endpoint is no longer available.", DeprecationWarning)
         return self.client.delete(self._url())
 
     def get(self, id, fields=None, include_fields=True):
